==> qmmp-0.12.4.tar.bz2: qmmp-0.12.4/src/plugins/Effect/soxr/translations/soxr_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>EffectSoXRFactory</name>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="31"/>
        <source>SoX Resampler Plugin</source>
        <translation>Plugin SoX de rééchantillonnage</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="52"/>
        <source>About SoX Resampler Plugin</source>
        <translation>A propos du plugin SoX de rééchantillonnage</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="53"/>
        <source>Qmmp SoX Resampler Plugin</source>
        <translation>Plugin SoX Qmmp de rééchantillonnage</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>SoX Resampler Settings</source>
        <translation>Paramètres du rééchantillonneur SoX</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Sample Rate (Hz):</source>
        <translation>Taux d&apos;échantillonnage (Hz) :</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="49"/>
        <source>Quality:</source>
        <translation>Qualité:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>Quick</source>
        <translation>Rapide</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>Low</source>
        <translation>Bas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Medium</source>
        <translation>Moyenne</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>High</source>
        <translation>Haut</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Very High</source>
        <translation>Très Haut</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.20.tar.bz2: qmmp-0.12.20/src/plugins/Effect/soxr/translations/soxr_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>EffectSoXRFactory</name>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="31"/>
        <source>SoX Resampler Plugin</source>
        <translation>Plugin SoX de rééchantillonnage</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="52"/>
        <source>About SoX Resampler Plugin</source>
        <translation>A propos du plugin SoX de rééchantillonnage</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="53"/>
        <source>Qmmp SoX Resampler Plugin</source>
        <translation>Plugin SoX Qmmp de rééchantillonnage</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>SoX Resampler Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Sample Rate (Hz):</source>
        <translation>Taux d&apos;échantillonnage (Hz) :</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="49"/>
        <source>Quality:</source>
        <translation>Qualité:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>Quick</source>
        <translation>Rapide</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>Low</source>
        <translation>Bas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Medium</source>
        <translation>Moyenne</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>High</source>
        <translation>Haut</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Very High</source>
        <translation>Très Haut</translation>
    </message>
</context>
</TS>
